@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 4277 2008-10-05 21:46:30Z wwalker $"
-__version__   = "$Revision: 4277 $"
-__date__      = "$Date: 2008-10-05 17:46:30 -0400 (Sun, 05 Oct 2008) $"
+__id__        = "$Id: braillegenerator.py 4415 2009-01-09 16:17:15Z wwalker $"
+__version__   = "$Revision: 4415 $"
+__date__      = "$Date: 2009-01-09 11:17:15 -0500 (Fri, 09 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1085,7 +1085,8 @@ class BrailleGenerator:
         componentRegion = braille.Component(
             obj, text,
             indicator=settings.brailleRadioButtonIndicators[ \
-            int(state.contains(pyatspi.STATE_CHECKED))])
+            int(state.contains(pyatspi.STATE_CHECKED) \
+                or state.contains(pyatspi.STATE_PRESSED))])
         regions.append(componentRegion)
 
         return [regions, componentRegion]
