@@ -20,13 +20,14 @@
 """Provides getTextAttributeName method that maps each text attribute
 into its localized equivalent."""
 
-__id__        = "$Id: text_attribute_names.py 4221 2008-09-15 08:11:23Z wwalker $"
-__version__   = "$Revision: 4221 $"
-__date__      = "$Date: 2008-09-15 04:11:23 -0400 (Mon, 15 Sep 2008) $"
+__id__ = "$Id: text_attribute_names.py 4315 2008-11-03 17:25:34Z wwalker $"
+__version__   = "$Revision: 4315 $"
+__date__      = "$Date: 2008-11-03 12:25:34 -0500 (Mon, 03 Nov 2008) $"
 __copyright__ = "Copyright (c) 2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 from orca_i18n import Q_        # to provide qualified translatable strings
+import orca_state
 
 # Translators: this is a structure to assist in the generation of
 # localized strings for the various text attributes. 
@@ -145,6 +146,14 @@ _textAttributeTable["font-effect"] = Q_("textattr|font effect")
 #
 _textAttributeTable["indent"] = Q_("textattr|indent")
 
+# Translators: this attribute specifies there is something "wrong" with
+# the text, such as it being a misspelled word. See:
+# https://developer.mozilla.org/en/Accessibility/AT-APIs/Gecko/TextAttrs
+#
+# ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+#
+_textAttributeTable["invalid"] = Q_("textattr|invalid")
+
 # Translators: this attribute specifies whether the text is invisible.
 # It will be a "true" or "false" value.
 # See
@@ -570,6 +579,14 @@ _textAttributeTable["right"] = Q_("textattr|right")
 #
 _textAttributeTable["center"] = Q_("textattr|center")
 
+# Translators: this is one of the text attribute values for the following
+# text attributes: "justification". In Gecko, when no justification has
+# be explicitly set, they report a justification of "start".
+#
+# ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+#
+_textAttributeTable["start"] = Q_("textattr|no justification")
+
 # Translators: this is one of the text attribute values for the following
 # text attributes: "justification".
 # See:
@@ -878,6 +895,21 @@ _textAttributeTable["rl"] = Q_("textattr|rl")
 #
 _textAttributeTable["tb"] = Q_("textattr|tb")
 
+# Translators: this is one of the text attribute values for the following
+# text attributes: "strikethrough." It refers to the line style.
+#
+# ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+#
+_textAttributeTable["solid"] = Q_("textattr|solid")
+
+# Translators: this is one of the text attribute values for the following
+# text attributes: "invalid". It is an indication that the text is not
+# spelled correctly. See:
+# https://developer.mozilla.org/en/Accessibility/AT-APIs/Gecko/TextAttrs
+#
+# ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+#
+_textAttributeTable["spelling"] = Q_("textattr|spelling")
 
 def getTextAttributeKey(localizedTextAttr):
     """Given a localized text attribute, return the original text 
@@ -912,6 +944,11 @@ def getTextAttributeName(textAttr):
     if isinstance(textAttr, unicode):
         textAttr = textAttr.encode("UTF-8")
 
+    # Normalize the name to an Atk name before attempting to look it up.
+    #
+    if orca_state.activeScript:
+        textAttr = orca_state.activeScript.getAtkNameForAttribute(textAttr)
+
     try:
         return _textAttributeTable[textAttr]
     except:
